@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "1.0.0"
 
 
 from beet import Context
@@ -11,6 +11,7 @@ def beet_default(ctx: Context):
         load(
             data_pack={"data/reapermc/modules": "@reapermc/modules"},
         ),
-        bolt(entrypoint=["*:main", "reapermc:reaper_cleanup"]),
+        bolt(entrypoint=["*:main", "reapermc:core"]),
         "bolt_expressions.plugin",
+        "reapermc.plugins.nbt_literals",
     )
